
# q-expansion of newform 4005.2.a.p, downloaded from the LMFDB on 13 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 4005
weight = 2
poly_data = [-1, 11, -27, -19, 34, 9, -11, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0], 1], [[0, -5, 0, 1, 0, 0, 0, 0], 1], [[-7, 65, 12, -76, -8, 23, 1, -2], 2], [[-7, 27, 18, -34, -9, 11, 1, -1], 1], [[-27, 121, 50, -144, -26, 45, 3, -4], 2], [[27, -136, -61, 170, 34, -55, -4, 5], 2], [[-29, 175, 72, -212, -42, 67, 5, -6], 2]]

hecke_ring_character_values = None
aps_data = [[0, -1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0], [-1, 2, 0, 1, 1, -1, 0, -1], [-2, 0, 1, 0, 0, 0, 0, 0], [-2, 1, 0, 1, 0, -2, -2, -1], [-2, 1, -1, 1, 1, 1, 0, 0], [3, -2, 0, -1, 0, 1, 1, 1], [1, 1, 0, 0, 1, 1, 2, 0], [-2, 2, 0, 0, 1, -1, -2, 1], [0, 0, 1, 0, -1, 1, 1, 2], [0, -1, -1, -1, 0, 2, 2, 1], [-2, -1, -1, -1, 0, 0, -2, 1], [-1, -3, 1, -2, -4, 0, 0, 1], [-1, 2, 1, -1, 0, -1, 2, 0], [2, -3, -2, -3, -2, 2, 2, 3], [-3, -1, 1, -2, -2, 1, 1, 0], [1, -1, -1, -2, -3, 2, -2, 2], [-3, 1, 2, 2, -1, 2, 4, 0], [-4, 0, 1, 0, -1, -1, 0, -1], [-1, -1, -3, 0, 1, 2, 0, 0], [-1, 1, 1, 0, 1, -4, 0, -2], [-6, 2, 0, 2, 1, -4, 0, -1], [-1, 0, 0, 0, 0, 0, 0, 0], [0, 3, -2, -1, 1, 1, -2, 0], [-2, -5, 1, -1, 0, 2, 0, -1], [1, -2, -2, -1, -1, 1, 4, 1], [-2, 0, 0, -4, -2, 2, 2, 4], [-5, 1, 1, 4, 1, -6, -6, 0], [-3, -2, 0, 3, 1, -2, -2, -3], [-7, -1, 0, 4, 0, 2, -2, -3], [-9, 1, -1, 0, 1, 0, -2, 0], [-3, 5, 3, -2, 1, -4, 2, 0], [4, -1, 0, 3, 3, 1, -2, 0], [2, -3, 1, 1, -2, 2, 0, -5], [0, 2, -3, 2, 5, 1, -1, -4], [1, 0, 2, -1, -2, 1, 4, 0], [1, -2, -1, 1, 3, -1, -2, 3], [-1, -4, 0, -1, 2, 1, -4, -2], [0, 6, 2, 2, -1, -1, 0, 1], [4, -2, -1, -2, 5, 1, 0, -1], [-1, 2, 0, 1, 0, 1, 4, -2], [-2, -1, -2, 3, 2, 4, 3, 2], [-2, 2, 0, 2, -1, -3, 2, 3], [-2, -1, -1, 1, -6, -2, -2, -5], [3, 0, 1, 3, -4, 1, 0, 0], [7, 1, 2, -2, -1, 2, 1, -1], [-1, -2, -1, 1, 3, 0, -2, -5], [-6, -4, 1, -4, -3, 3, 0, 1], [2, 0, -1, 2, 6, 4, 0, -2], [-3, 5, 3, 2, 0, -7, -4, -3], [-8, -6, -2, 4, -1, 1, -1, 2], [0, -2, 0, 2, -1, 5, -4, 1], [-3, -4, -4, -1, -2, 3, -4, 2], [0, 5, 2, 3, 3, -1, 4, -4], [-8, 5, 2, 1, 0, 2, -2, -1], [-3, -7, 1, -4, -2, -1, -2, 5], [-1, 0, 0, -7, -2, 5, 0, 2], [-9, -6, 3, -9, -6, 1, 0, 4], [-2, 1, 0, 1, -1, 3, 0, -4], [9, 2, -3, -1, 3, -2, -6, -1], [-6, -5, -3, -5, -1, 1, 2, 0], [-4, -5, 1, -1, -5, 3, 0, 6], [-5, 0, -1, 5, -1, -6, -2, -3], [-5, 1, 3, 2, -4, -1, 0, -3], [-1, 4, 3, 7, 1, -10, -12, -3], [-5, -3, 1, -4, -9, -2, 0, 0], [-9, -3, 3, -6, 0, 3, 2, 3], [-6, -1, 4, 1, 4, -4, 2, -3], [8, -7, 0, -1, 3, -1, -2, -2], [-3, 5, 1, -6, 1, 0, -2, 8], [8, 0, 0, 0, 0, 2, 9, 3], [-9, 5, -1, 2, 9, 2, 2, -4], [3, 5, 0, 6, 12, -3, 2, 3], [0, 0, 0, -2, 3, -1, -1, 0], [-3, 7, 2, 8, 8, -6, -2, -7], [0, -3, 0, -3, -2, 2, 6, -3], [-15, -4, 1, 1, -2, -7, -8, -6], [12, 2, 0, 4, 3, -1, 2, -1], [-7, 5, 0, 6, 0, -5, 4, 5], [-7, 0, 0, -1, 4, -5, -3, -1], [3, -10, 0, -7, 2, 9, 8, 4], [0, 17, 0, 1, 3, -5, -1, -3], [-6, 13, 0, 11, 5, -9, -4, -10], [5, -17, 3, -10, -10, 11, 7, 6], [10, -4, -4, -10, -1, 1, 2, 5], [10, -1, 0, 3, -5, -3, 0, 2], [-5, 6, -2, 7, 10, 3, 2, -6], [11, -5, -4, -8, -3, 8, -4, 8], [-9, -9, 1, -4, -7, -2, 2, -2], [-14, 7, 5, 1, -3, -5, -4, 0], [-10, 3, 2, 15, 6, -4, -4, -7], [-5, -16, -2, 5, -1, 8, 0, 3], [-15, 4, 4, 5, -1, -6, -1, -4], [5, -1, 1, 8, 1, -10, -7, -5], [-10, 8, -1, 10, 3, -6, -2, -11], [6, -4, 1, -4, -2, 0, 0, 2], [-5, 12, 3, 3, -3, -6, 4, 1], [0, 7, -3, 7, 7, -1, 0, 2], [13, -2, -5, -5, -5, 10, 6, 7], [4, -7, -1, -9, -1, 6, -2, 2], [11, -9, 3, -12, -8, -3, 2, 1], [-17, 8, 0, 13, 0, -12, -8, -4], [9, -5, -2, -6, -4, 1, 2, 5], [3, 5, 5, 4, -3, -10, -5, -5], [10, 15, -2, 7, 10, -10, -4, 1], [-10, 1, -4, -5, 2, 8, 6, 1], [5, -1, -1, -14, -4, 1, -6, -3], [0, -3, -1, 3, 5, 5, -3, 1], [-6, 6, 7, 6, -1, -5, 6, 3], [-13, -7, 3, -4, -2, 3, -2, 13], [0, -6, 0, -2, -6, 0, 2, 8], [7, -9, -5, -10, -5, 8, 6, 8], [2, 11, 4, 9, -1, 3, 4, 2], [7, 13, 1, 2, 4, -11, -2, -9], [-1, 11, -2, 4, 0, -3, 2, -11], [2, 10, 5, 8, 6, -14, -4, -4], [0, -8, 1, -4, -1, -2, -2, 1], [1, -8, 3, -9, -1, 8, 10, 1], [4, 4, -5, 4, 5, 5, 0, -3], [12, -6, -3, 0, 3, 7, 8, -3], [3, 1, 3, -2, 10, 5, 6, -1], [-3, 5, 4, 4, 5, -12, -4, -2], [6, -13, 0, -9, -6, 9, -4, -3], [7, 12, -2, 7, 3, -8, -4, -9], [7, 6, 3, 7, 4, -9, -4, -10], [13, -3, 5, 2, -2, -5, 2, 5], [-2, -10, -5, -2, -4, 6, 3, 3], [-5, 6, 1, 7, 3, 1, 6, -1], [20, 7, 5, -3, 1, -1, 0, -6], [2, 5, 0, -1, -5, -5, -3, -9], [18, 2, 0, -10, -3, -2, 4, 11], [1, 6, -2, 5, 2, -9, -12, -4], [-18, 4, 5, -2, -3, -3, -4, 3], [-8, -2, 4, 2, -6, -4, -6, -2], [8, 3, -5, -5, -4, 0, 0, 3], [-10, -1, 7, 3, -1, -7, 2, 4], [4, 0, 0, 2, -7, 0, -2, 3], [14, -14, -2, -8, 1, 3, 0, 7], [-9, -8, -1, 3, 5, -2, 0, 1], [0, -2, -1, -4, 0, 6, -6, 0], [13, 2, -3, 3, 8, 1, 2, 4], [-7, -10, 0, 3, -4, 1, -8, 6], [-6, -12, 1, -10, -3, 6, 2, -1], [-5, -10, -5, -3, -1, -2, -2, -1], [-1, -12, 3, -15, -7, 14, 13, 4], [11, -8, 4, -9, -3, 10, 0, 9], [3, 0, -8, -3, 6, -1, -2, 8], [1, 3, -2, 4, 2, 3, -1, 6], [10, 9, -3, 19, 8, -1, 0, -7], [3, -16, -1, -7, -3, 4, -8, -3], [-3, 20, -6, 5, 13, -6, -4, -3], [4, 6, 3, -6, -1, -8, 6, 3], [-12, 11, 0, 1, -2, 5, -4, -3], [1, 21, -1, 16, 11, -4, 2, -14], [-3, -15, 2, -4, -15, 4, 0, -2], [4, -12, -2, 0, -2, 10, 3, 11], [0, 1, 0, 15, 5, -7, -12, -14], [7, -5, -3, 0, 3, 0, 12, -6], [6, -4, -4, -8, 6, 14, 10, 8], [1, -13, -4, -6, -8, 1, 12, -1], [3, 5, 2, 0, 4, 5, 4, -7], [-19, -3, 1, -10, -5, 5, 0, 12], [3, 14, -6, -1, 2, -3, -10, 2], [8, 1, 0, 7, 1, 1, 8, 2], [25, -2, -6, 3, -4, 11, 12, 6], [-2, 18, 2, 10, 1, -7, 1, -6], [-2, 13, -2, 1, 9, -13, -4, -6], [1, 17, 0, 2, 5, -10, -2, -8], [1, 13, -1, -2, 3, -2, 10, 0], [-19, 16, 5, 3, 1, -10, -4, -7], [-3, 6, -3, 9, 3, -6, -2, 3], [-10, -16, -3, -8, -8, -2, -11, 7], [5, 6, -7, -7, -1, 6, 8, 1], [18, 8, 0, 4, 5, 7, 15, -6], [3, 8, 1, 7, 15, 0, -8, -5], [-4, 21, -2, 11, 12, -12, -6, -13], [-12, 2, -2, 12, 10, 0, -2, 6], [10, -2, -1, -18, 1, 7, 0, 3], [-10, 12, 3, 12, 4, -10, -12, -4], [-15, -5, -2, -6, -9, 3, -8, -2], [-24, 2, 3, 10, 5, 3, 1, -2], [3, -15, -8, -2, -1, 14, 4, 2], [19, -4, -1, -1, -4, 7, 8, -4], [9, 7, 2, 4, -4, 4, 2, -3], [2, 2, 7, 6, -5, -1, 4, -3], [1, 2, 4, 3, -11, 6, 8, -3], [-18, 16, -4, -2, 11, -3, -2, -3], [15, 16, 4, -3, 5, -2, 6, -1], [-12, 15, -10, 9, 4, 2, -9, 0], [-12, 11, 2, 3, 5, -23, -6, -8], [-8, 2, 2, 6, -4, -13, -14, 0], [19, -4, -2, 7, 7, -4, -5, -4], [15, -16, -3, -19, -16, 9, 6, 14], [-38, 3, -5, 9, 2, -3, -6, 3], [-1, -3, -4, 10, 3, -6, 8, -10], [15, -19, 1, -6, -3, 6, -8, 2], [9, -17, -3, -18, -8, 11, -2, 21], [4, 11, 9, 1, 1, -17, -2, -10], [0, 3, -6, -3, 10, -3, -16, -3], [4, -8, 3, -4, -3, -13, -4, -3], [-5, 28, 0, 27, 13, -14, -1, -10], [5, -1, -5, -16, 2, 11, 12, 9], [-14, 1, 4, 9, 5, -17, -16, -18], [1, 15, -3, 20, 13, -2, 3, -11], [-9, 6, 0, 9, 5, -14, -14, -3], [7, -23, 0, -2, -5, -2, -3, 11], [-3, -14, 4, 3, -3, -13, -4, -9], [-24, -7, 0, -13, -11, 5, 0, 6], [0, -2, 7, 2, 5, 1, 14, 1], [0, 0, -4, 20, 6, -4, -2, -12], [14, -14, -1, -6, -16, 18, 0, 6], [-24, 8, 1, -8, -8, 14, 0, -4], [-27, 3, 3, -6, -6, -2, -6, 7], [-2, 20, 5, -10, 3, -11, 2, -3], [-9, -8, -11, -1, 3, -2, 0, 11], [-9, 13, 2, 4, 5, -12, 4, 6], [-1, 3, -5, 8, 7, -4, -16, -6], [15, 17, 3, 2, 3, -6, 10, -10], [-6, -1, -4, 7, -2, 4, -8, -3], [11, 8, 7, -7, 0, -15, 2, 2], [-4, 8, 2, 16, 0, -4, -2, -14], [-13, 13, -2, 2, 10, -9, -10, -3], [-19, 4, 4, -5, 3, -8, 8, -1], [0, -4, 1, 4, -9, 12, 4, -5], [-15, 7, 5, -4, 6, -5, 8, 1], [-5, -9, 0, -4, -8, -3, 2, 9], [0, -7, 1, -7, -6, 8, 11, 8], [-7, 13, 7, 12, -4, -4, 4, -11], [-5, -24, 1, -23, -23, 12, -1, 10], [0, 1, 8, -13, -10, -2, -4, -1], [10, 7, 2, 1, 3, 15, 3, 7], [-2, -29, 3, -23, -16, 12, 4, 7], [9, -12, 8, -11, -16, -5, 6, 6], [-23, -9, -1, -14, -8, 2, 4, 7], [-7, -1, 8, 4, -6, 6, 12, 13], [-13, 2, 1, 17, 7, -6, -20, -3], [-1, 26, -6, 23, 17, -12, 2, -3], [33, -10, -2, -5, -3, 14, 11, 12], [-4, 2, 4, 18, 4, -8, -14, -16], [13, -25, 4, -8, -17, 18, 8, 2], [6, -7, 2, 5, 10, 0, -4, -1], [-3, -1, -1, -4, 3, 5, 10, -4], [-11, -15, -7, -6, -9, 10, -2, 6], [5, 0, -8, -1, 12, -1, -4, 2], [-12, 22, -7, 12, 12, -10, -13, -9], [8, 5, 1, -13, 7, 8, 6, -2], [31, -11, -5, -4, -3, 8, 17, 9], [-2, -2, -1, -4, 11, 15, 13, 8], [16, 7, 5, 5, 1, 0, 20, 8], [11, 0, -2, -7, -1, 22, 22, 5], [-3, 32, -6, 25, 19, -20, -8, -13], [8, -9, 2, -11, 5, 13, 2, -2], [-8, 0, 0, 0, -9, -3, -4, 3], [-12, 8, 3, 8, 13, -9, -4, 11], [-12, 5, -2, -3, 1, 11, 12, 2], [9, -12, 4, -9, -1, 4, -12, -5], [-3, -26, -2, -21, -20, 11, -8, 14], [32, 0, -4, -6, -3, 15, 6, -5], [-15, 17, -5, 16, 14, -5, 10, 7], [7, 16, -1, 3, 8, 12, 6, -2], [-5, -33, -3, -16, -4, 12, 2, 9], [-4, -3, -13, 1, 0, 0, -4, -7], [-4, 25, 3, 3, 7, -11, 12, -2], [-11, -5, -4, -4, 2, 1, -6, -5], [3, -6, -1, -15, -10, -5, -8, -4], [10, 9, -5, -5, 1, -7, 2, -8], [-3, -12, -2, -9, -23, 2, 10, 15], [15, -13, -3, 6, 8, -7, -10, 1], [-6, -15, -5, -3, -1, -1, -4, 10], [-3, 9, 4, -10, 10, -7, 0, -5], [14, -10, 5, -2, -8, 9, 14, -8], [-1, 15, -3, 4, 2, -3, 16, 9], [10, 19, 0, 17, 5, -3, 8, 0], [-7, 4, 2, 11, 4, -9, -2, -14], [-33, 10, 8, 15, 8, -24, -12, 6], [-4, -1, -1, -9, 2, -19, -2, 3], [-15, 12, -5, -3, 11, 6, 0, 3], [6, 7, 3, 7, -6, -20, -26, -1], [2, 9, 6, 1, -2, 0, 11, -4], [-2, 6, 10, 8, 2, -11, 2, 10], [9, 1, 0, -10, 2, 11, 9, 18], [-20, -13, 0, -5, -4, 6, 6, 1], [6, -28, -9, -20, -19, 17, 6, 23], [-34, 17, 1, 13, 2, -14, -12, -17], [11, -5, 4, 0, -1, -4, 10, 0], [-14, 6, -9, -6, 0, 10, 16, 16], [-15, -6, -1, 1, -4, 13, 8, 6], [-13, -31, 8, -16, -14, -7, -2, 1], [8, -5, 0, 3, -4, -14, -8, -13], [-6, 3, -3, 17, 8, 6, 4, -5], [-8, -3, -10, -1, 12, 1, -12, 1], [11, 11, 4, 0, 7, 6, 8, -12], [-19, 19, -5, 14, 18, -9, 17, -4], [26, -13, -12, -11, 6, 22, 0, -3], [-25, -1, -4, -2, -2, 3, 8, 5], [19, -11, -15, 10, 8, 15, -9, -2], [10, -11, 3, -19, -5, 5, 2, -2], [-3, -4, -11, -21, 3, 8, 4, 11], [5, 7, -5, -8, -1, -1, 2, 0], [-5, 0, -7, 9, 5, 2, -12, -7], [-8, -9, 3, -1, -4, 4, 0, 5], [-8, 6, -2, -16, -1, 1, -1, 2], [23, 19, 0, -16, -4, -7, 4, -1], [7, -4, 8, -9, -5, -8, 14, -3], [17, -15, 2, -4, -1, 8, -8, 0], [15, 16, -10, 13, 5, -2, 8, -3], [17, 17, 1, 18, 21, -8, 6, -20], [12, -18, -3, -12, -14, 8, 10, 2], [5, -23, 5, 8, -12, -1, 0, 1], [-28, 27, 3, 25, 16, -16, -8, -21], [21, -21, -2, -10, -18, 21, 6, 15], [-3, 16, -5, -11, 3, 10, 4, -5], [-9, 1, 9, 0, -8, 5, -6, -13], [26, -10, -1, -2, -9, 9, 4, 5], [4, 21, 2, 29, 14, -12, 4, -5], [6, -18, -13, -14, 0, 22, 1, -3], [4, 8, 5, 0, -5, -1, 0, -13], [-19, 14, -1, 21, 5, -16, -10, -7], [-2, 1, 2, -3, 21, 9, 16, 2], [21, 3, -4, 8, 4, 1, 0, -13], [3, -9, 12, 2, -8, 13, 0, 1], [20, -22, -7, -14, 1, 19, 0, -1], [-12, -14, 2, -12, -7, -6, -12, 19], [-7, 10, -1, -15, 2, 11, -4, -8], [-22, -3, 4, -3, -17, 13, 0, -4], [10, 3, -8, 13, 1, 5, 7, -7], [0, 8, -1, 12, 4, -6, -4, 0], [9, -9, 1, 6, -3, 10, -6, -2], [-9, -33, 6, -20, -23, 10, 4, 4], [8, -1, 4, -9, -3, 9, -14, 2], [-39, 19, -4, 16, 2, -9, -10, -25], [38, 7, -1, 9, 10, -6, -11, 0], [4, -2, -6, 4, 4, 2, -18, 4], [10, -3, -9, 15, 4, 14, 5, 4], [-15, 22, 13, 1, 0, -9, -6, -8], [2, -14, -3, -20, -18, 12, 18, 14], [3, 18, -1, -11, 18, 5, -8, -8], [8, -15, -6, -7, -10, -2, -16, -1], [17, 0, -1, 1, 12, 4, -2, -14], [-8, 16, -4, 4, -12, -10, 2, 0], [20, -5, -4, -9, -4, 6, 4, 7], [-3, 27, -2, 12, 4, -17, -16, -9], [-26, 18, 7, 2, 0, -16, -15, -15], [-13, -5, -1, -4, -6, -5, -14, -1], [-8, -6, -12, -12, 1, 19, 8, 27], [-10, -28, -4, -6, -5, 7, -10, 9], [-3, -10, 9, 11, -8, -4, 8, -10], [-2, 9, 11, -5, -8, 0, -9, -6], [21, -11, -1, -26, -1, 12, 4, 24], [5, -10, -2, -15, -6, -1, 2, 6], [-5, 20, 1, 5, -3, -10, -4, 1], [-26, -4, -2, -2, 13, -1, -8, 13], [6, 15, -2, -5, 7, -23, -14, -16], [-4, 26, 7, -6, 8, -20, -4, -2], [-15, 4, -6, -9, 9, -10, 2, -1], [-16, 5, -2, 1, 3, 5, 10, -10], [-16, 4, 8, -6, -13, -3, 10, -3], [29, 16, 5, -11, 10, -9, 8, -2], [-1, 4, 4, 5, -5, 8, 8, -1], [14, -13, -2, 1, -13, 5, -2, -10], [-1, -5, -1, -18, -2, -15, 0, -3], [1, -9, -3, -14, 3, -12, -6, 4], [-5, -16, -6, 19, -1, 6, 1, -10], [20, 4, 15, 6, -9, -15, -8, -5], [18, -12, 9, -4, -2, 8, 8, -6], [-21, 33, 4, 18, -7, -18, -16, 2], [-14, -4, -1, -10, -8, 16, 8, 24], [-14, -2, 9, 18, 1, -9, -2, -15], [-13, 11, 8, 10, 16, -1, -18, -3], [-27, 12, 7, -1, 7, -8, -10, 1], [6, -9, -3, -7, -8, -15, -8, -5], [20, -2, 0, -10, -1, 11, 28, -3], [14, -18, -1, -4, -15, 27, 5, -6], [-4, -6, 6, -2, -2, -14, -18, 6], [14, -30, 3, 2, -14, 10, -12, 4], [-17, 4, 6, 11, 15, -4, 6, -7], [-4, 7, -3, 1, 21, 7, 8, -8], [-14, 9, 7, 13, -2, -6, 10, 13], [-6, 6, -2, 10, 16, -12, -8, -18], [-2, 19, -6, 17, 8, -4, -12, -5], [10, 5, -7, 9, 11, 23, 6, -6], [15, -23, 1, 14, 4, 0, 8, 9], [38, 23, 2, 9, 15, 5, 6, -4], [-24, 5, -2, -1, -4, -8, -12, -19], [-15, -12, -1, -3, -12, 20, 6, 14], [3, 22, -1, 3, 11, -2, 4, -7], [13, 28, -4, 35, 20, -11, -6, -10], [-26, 5, -1, -15, 11, -4, 8, 4], [8, 13, -3, 5, 3, -5, -4, 4], [6, -10, -12, -12, 15, 7, -4, -7], [21, 4, -17, 11, 7, 0, -6, -3], [7, 20, 5, 11, 24, -9, 17, -1], [4, -12, -21, 2, -4, 9, -6, 6], [-2, -2, -2, -6, -13, 3, 1, 12], [34, -22, 0, 6, 3, -3, -2, -1], [5, -12, 7, -17, -15, 2, -2, -1], [-13, 9, 6, 16, -9, -6, -14, -2], [1, 8, 10, 19, 4, -3, 9, -1], [-2, 0, 4, -10, -16, -12, -22, -2], [1, -7, 2, -24, -10, 9, 18, 9], [-15, -11, 6, -4, -17, -4, -10, 2], [10, -22, -1, -22, -21, 13, 8, 13], [-37, 23, -10, 18, 14, 3, -8, 3], [-13, 9, 15, 16, 22, -9, -2, -7], [28, 23, -6, 23, 19, -23, -10, -24], [23, 19, -2, 2, 6, -7, -16, 1], [8, -21, 5, -17, -23, 3, -6, 10], [-43, -19, -2, 12, 0, 5, -4, 13], [18, -27, 8, -29, -23, 1, 5, 9], [-41, -11, -7, 0, -13, -4, -12, 4], [-4, 18, -8, 12, -8, -6, -12, -2], [17, -4, 1, 9, 19, 4, 2, 1], [28, -5, -6, 3, 11, 11, 11, 3], [-3, 18, -1, 25, 15, -18, 6, -7], [-23, 5, 6, 6, 1, -2, 0, 6], [-11, -14, -7, -3, 3, -14, -17, 6], [-11, 29, -1, 18, 12, -35, -22, -1], [16, 17, 3, -9, -3, -13, 12, -4], [-13, 11, 5, 10, -8, -9, -2, 9], [6, 38, -1, 32, 32, -36, -8, -6], [24, -1, -1, -21, 1, 3, 6, 18], [-12, -3, -2, 11, 9, -5, -18, 8], [-29, -9, 7, 6, -13, -10, 2, 12], [-9, -7, 4, 10, -6, 3, -2, -15], [-34, 14, 12, 12, -7, -13, 8, -5], [-4, 3, -2, -19, 14, -11, 4, 5], [-14, -32, 0, -4, -13, 21, -2, 1], [5, -23, -9, -6, 3, 24, 16, 16], [-10, 5, 3, -5, -6, -14, 5, -2]]
